# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`st2`](#st2): Base class for st2 module. Used as top-level to set parameters via Hiera, this class does not need to be called directly.
* [`st2::auth`](#st2auth): Class to configure authentication for StackStorm.
* [`st2::auth::common`](#st2authcommon): Class that contains all of the "common" settings for auth.
* [`st2::auth::flat_file`](#st2authflat_file): Auth class to configure and setup Flat File (htpasswd) Authentication
* [`st2::auth::keystone`](#st2authkeystone): Auth class to configure and setup Keystone Based Authentication
* [`st2::auth::ldap`](#st2authldap): Auth class to configure and setup LDAP Based Authentication
* [`st2::auth::mongodb`](#st2authmongodb): Auth class to configure and setup MongoDB Based Authentication
* [`st2::auth::pam`](#st2authpam): Auth class to configure and setup PAM authentication.
* [`st2::kvs`](#st2kvs): Automatically loads Key/Value pairs for StackStorm DB from Hiera
* [`st2::logging::rsyslog`](#st2loggingrsyslog): Helper class to route syslog messages when using rsyslog
* [`st2::notices`](#st2notices): This is a private class used to store long strings to limit down on lint problems.
* [`st2::notifier`](#st2notifier): Manages the <code>st2notifier</code> service (Orquesta)
* [`st2::packs`](#st2packs): Install and configure st2 packages in bulk and via Hiera.
* [`st2::params`](#st2params): Main parameters to manage the st2 module
* [`st2::profile::chatops`](#st2profilechatops): Profile to install and configure chatops for st2
* [`st2::profile::client`](#st2profileclient): Profile to install, configure and manage all client libraries for st2
* [`st2::profile::facter`](#st2profilefacter): Setup custom fact locations
* [`st2::profile::fullinstall`](#st2profilefullinstall): This class performs a full default install of StackStorm and all its components on a single node.
* [`st2::profile::mongodb`](#st2profilemongodb): StackStorm compatable installation of MongoDB and dependencies.
* [`st2::profile::nginx`](#st2profilenginx): StackStorm compatible installation of nginx and dependencies.
* [`st2::profile::nodejs`](#st2profilenodejs): st2 compatable installation of NodeJS and dependencies for use with StackStorm.
* [`st2::profile::python`](#st2profilepython): StackStorm compatable installation of Python and dependencies.
* [`st2::profile::rabbitmq`](#st2profilerabbitmq): StackStorm compatable installation of RabbitMQ and dependencies.
* [`st2::profile::redis`](#st2profileredis): StackStorm compatable installation of Redis.
* [`st2::profile::selinux`](#st2profileselinux): Configure SELinux so that StackStorm services run properly
* [`st2::profile::server`](#st2profileserver): Profile to install, configure and manage all server components for st2
* [`st2::profile::web`](#st2profileweb): Profile to install, configure and manage StackStorm web UI (st2web).
* [`st2::repo`](#st2repo): Manages the installation of st2 required repos for installing the StackStorm packages.
* [`st2::repo::apt`](#st2repoapt): Apt repo for StackStorm
* [`st2::repo::yum`](#st2repoyum): Yum repo for StackStorm
* [`st2::rulesengine`](#st2rulesengine): Manages the <code>st2rulesengine</code> service (Orquesta)
* [`st2::scheduler`](#st2scheduler): Manages the <code>st2scheduler</code> service.
* [`st2::server::datastore_keys`](#st2serverdatastore_keys): Generates and manages crypto keys for use with the StackStorm datastore
* [`st2::stanley`](#st2stanley): Installs the default admin user for st2 (stanley).
* [`st2::timersengine`](#st2timersengine): Manages the <code>st2timersengine</code> service.
* [`st2::workflowengine`](#st2workflowengine): Manages the <code>st2workflowengine</code> service (Orquesta)

### Defined types

* [`st2::auth_user`](#st2auth_user): Creates and manages StackStorm application users (flat_file auth only)
* [`st2::client::settings`](#st2clientsettings): Generates a configuration file for the st2 CLI (st2client)
* [`st2::kv`](#st2kv): Sets a value to the StackStorm Key/Value Store
* [`st2::pack`](#st2pack): Manages a StackStorm Pack
* [`st2::rbac`](#st2rbac): This defined type creates RBAC resources for users
* [`st2::service`](#st2service): Creates additional service for components that can be scaled out
* [`st2::user`](#st2user): Creates an system (OS level) user for use with StackStorm

### Resource types

* [`st2_pack`](#st2_pack): Manage st2 packs

### Functions

* [`st2::urlencode`](#st2urlencode): URL encodes a string
* [`st2::version_ge`](#st2version_ge): Determines if the StackStorm version installed or the version requested
by the user is greater than or equal to <code>$version</code>.

### Data types

* [`St2::Repository`](#st2repository): Validate the type of system package repository for StackStorm

### Tasks

* [`key_decrypt`](#key_decrypt): Decrypt a StackStorm key/value pair. TODO - Remove this when the following is closed: https://github.com/StackStorm/st2/issues/4545
* [`key_get`](#key_get): Retrieve the value for a key from the StackStorm datastore
* [`key_load`](#key_load): Load a list of a StackStorm key/value pairs into the datastore
* [`pack_install`](#pack_install): Install a list of packs
* [`pack_list`](#pack_list): Get a list of packs
* [`pack_register`](#pack_register): Registers a pack that exists on the filesystem
* [`pack_remove`](#pack_remove): Remove a list of packs
* [`rule_disable`](#rule_disable): Disable a given rule
* [`rule_list`](#rule_list): Return a list of rules.
* [`run`](#run): Runs a StackStorm action

### Plans

* [`st2::upgrade_mongodb`](#st2upgrade_mongodb): Upgrades a standalone MongoDB database between versions.

## Classes

### <a name="st2"></a>`st2`

Base class for st2 module. Used as top-level to set parameters via Hiera, this class does not need to be called directly.

#### Examples

##### Basic Usage

```puppet
include st2
```

##### Variables can be set in Hiera and take advantage of automatic data bindings:

```puppet
st2::version: 2.10.1
```

##### Customizing parameters

```puppet
# best practice is to change default username/password
class { 'st2::params':
  admin_username => 'st2admin',
  admin_password => 'SuperSecret!',
}

class { 'st2':
  version => '2.10.1',
}
```

##### Different passwords for each database (MongoDB, RabbitMQ)

```puppet
class { 'st2':
  # StackStorm user
  cli_username        => 'st2admin',
  cli_password        => 'SuperSecret!',
  # MongoDB user for StackStorm
  db_username         => 'admin',
  db_password         => 'KLKfp9#!2',
  # RabbitMQ user for StackStorm
  rabbitmq_username   => 'st2',
  rabbitmq_password   => '@!fsdf0#45',
}
```

##### Install with python 3.8 (if not default on your system)

```puppet
$st2_python_version = $facts['os']['family'] ? {
  'RedHat' => '3.8',
  'Debian' => 'python3.8',
}
class { 'st2':
  python_version            => $st2_python_version,
}
```

#### Parameters

The following parameters are available in the `st2` class:

* [`version`](#version)
* [`python_version`](#python_version)
* [`repository`](#repository)
* [`conf_dir`](#conf_dir)
* [`conf_file`](#conf_file)
* [`use_ssl`](#use_ssl)
* [`ssl_cert_manage`](#ssl_cert_manage)
* [`ssl_dir`](#ssl_dir)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`auth`](#auth)
* [`auth_api_url`](#auth_api_url)
* [`auth_debug`](#auth_debug)
* [`auth_mode`](#auth_mode)
* [`auth_backend`](#auth_backend)
* [`auth_backend_config`](#auth_backend_config)
* [`cli_base_url`](#cli_base_url)
* [`cli_api_version`](#cli_api_version)
* [`cli_debug`](#cli_debug)
* [`cli_cache_token`](#cli_cache_token)
* [`cli_username`](#cli_username)
* [`cli_password`](#cli_password)
* [`cli_apikey`](#cli_apikey)
* [`cli_api_url`](#cli_api_url)
* [`cli_auth_url`](#cli_auth_url)
* [`actionrunner_workers`](#actionrunner_workers)
* [`packs`](#packs)
* [`packs_group`](#packs_group)
* [`index_url`](#index_url)
* [`syslog`](#syslog)
* [`syslog_host`](#syslog_host)
* [`syslog_protocol`](#syslog_protocol)
* [`syslog_port`](#syslog_port)
* [`syslog_facility`](#syslog_facility)
* [`ssh_key_location`](#ssh_key_location)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_bind_ips`](#db_bind_ips)
* [`db_name`](#db_name)
* [`db_username`](#db_username)
* [`db_password`](#db_password)
* [`mongodb_version`](#mongodb_version)
* [`mongodb_manage_repo`](#mongodb_manage_repo)
* [`mongodb_auth`](#mongodb_auth)
* [`nginx_manage_repo`](#nginx_manage_repo)
* [`nginx_ssl_ciphers`](#nginx_ssl_ciphers)
* [`nginx_ssl_protocols`](#nginx_ssl_protocols)
* [`nginx_ssl_port`](#nginx_ssl_port)
* [`nginx_client_max_body_size`](#nginx_client_max_body_size)
* [`web_root`](#web_root)
* [`timersengine_enabled`](#timersengine_enabled)
* [`timersengine_timezone`](#timersengine_timezone)
* [`scheduler_sleep_interval`](#scheduler_sleep_interval)
* [`scheduler_gc_interval`](#scheduler_gc_interval)
* [`scheduler_pool_size`](#scheduler_pool_size)
* [`chatops_adapter`](#chatops_adapter)
* [`chatops_adapter_conf`](#chatops_adapter_conf)
* [`chatops_hubot_log_level`](#chatops_hubot_log_level)
* [`chatops_hubot_express_port`](#chatops_hubot_express_port)
* [`chatops_tls_cert_reject_unauthorized`](#chatops_tls_cert_reject_unauthorized)
* [`chatops_hubot_name`](#chatops_hubot_name)
* [`chatops_hubot_alias`](#chatops_hubot_alias)
* [`chatops_api_key`](#chatops_api_key)
* [`chatops_st2_hostname`](#chatops_st2_hostname)
* [`chatops_api_url`](#chatops_api_url)
* [`chatops_auth_url`](#chatops_auth_url)
* [`chatops_web_url`](#chatops_web_url)
* [`nodejs_version`](#nodejs_version)
* [`nodejs_manage_repo`](#nodejs_manage_repo)
* [`redis_bind_ip`](#redis_bind_ip)
* [`workflowengine_num`](#workflowengine_num)
* [`scheduler_num`](#scheduler_num)
* [`rulesengine_num`](#rulesengine_num)
* [`notifier_num`](#notifier_num)
* [`erlang_url`](#erlang_url)
* [`erlang_key`](#erlang_key)
* [`validate_output_schema`](#validate_output_schema)
* [`cli_silence_ssl_warnings`](#cli_silence_ssl_warnings)
* [`ng_init`](#ng_init)
* [`datastore_keys_dir`](#datastore_keys_dir)
* [`datastore_key_path`](#datastore_key_path)
* [`rabbitmq_username`](#rabbitmq_username)
* [`rabbitmq_password`](#rabbitmq_password)
* [`rabbitmq_hostname`](#rabbitmq_hostname)
* [`rabbitmq_port`](#rabbitmq_port)
* [`rabbitmq_bind_ip`](#rabbitmq_bind_ip)
* [`rabbitmq_vhost`](#rabbitmq_vhost)
* [`redis_hostname`](#redis_hostname)
* [`redis_port`](#redis_port)
* [`redis_password`](#redis_password)

##### <a name="version"></a>`version`

Data type: `Any`

Version of StackStorm package to install (default = 'present')
See the package 'ensure' property:
https://puppet.com/docs/puppet/5.5/types/package.html#package-attribute-ensure

Default value: `'present'`

##### <a name="python_version"></a>`python_version`

Data type: `String`

Version of Python to install. Default is 'system' meaning the system version
of Python will be used.
To install Python 3.8 on RHEL/CentOS 7 specify '3.8'.
To install Python 3.8 on Ubuntu 16.05 specify 'python3.8'.

Default value: `'system'`

##### <a name="repository"></a>`repository`

Data type: `St2::Repository`

Release repository to enable. 'stable', 'unstable'
(default = 'stable')

Default value: `$st2::params::repository`

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Any`

The directory where st2 configs are stored

Default value: `$st2::params::conf_dir`

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `"${st2::params::conf_dir}/st2.conf"`

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Any`

Enable/Disable SSL for all st2 APIs

Default value: `$st2::params::use_ssl`

##### <a name="ssl_cert_manage"></a>`ssl_cert_manage`

Data type: `Any`

Boolean to determine if this module should manage the SSL certificate used by nginx.

Default value: ``true``

##### <a name="ssl_dir"></a>`ssl_dir`

Data type: `Any`

Directory where st2web will look for its SSL info.
(default: /etc/ssl/st2)

Default value: `$st2::params::ssl_dir`

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Any`

Path to the file where the StackStorm SSL cert will
be generated. (default: /etc/ssl/st2/st2.crt)

Default value: `$st2::params::ssl_cert`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Any`

Path to the file where the StackStorm SSL key will
be generated. (default: /etc/ssl/st2/st2.key)

Default value: `$st2::params::ssl_key`

##### <a name="auth"></a>`auth`

Data type: `Any`

Toggle to enable/disable auth (Default: true)

Default value: ``true``

##### <a name="auth_api_url"></a>`auth_api_url`

Data type: `Any`

URL where StackStorm auth service will communicate
with the StackStorm API service

Default value: `"http://${st2::params::hostname}:${st2::params::api_port}"`

##### <a name="auth_debug"></a>`auth_debug`

Data type: `Any`

Toggle to enable/disable auth debugging (Default: false)

Default value: ``false``

##### <a name="auth_mode"></a>`auth_mode`

Data type: `Any`

Auth mode, either 'standalone' or 'backend (default: 'standalone')

Default value: `$st2::params::auth_mode`

##### <a name="auth_backend"></a>`auth_backend`

Data type: `Any`

Determines which auth backend to configure. (default: flat_file)
Available backends:
- flat_file
- keystone
- ldap
- mongodb
- pam

Default value: `$st2::params::auth_backend`

##### <a name="auth_backend_config"></a>`auth_backend_config`

Data type: `Any`

Hash of parameters to pass to the auth backend
class when it's instantiated. This will be different
for every backend. Please see the corresponding
backend class to determine what the config options
should be.

Default value: `$st2::params::auth_backend_config`

##### <a name="cli_base_url"></a>`cli_base_url`

Data type: `Any`

CLI config - Base URL lives

Default value: `"http://${st2::params::hostname}"`

##### <a name="cli_api_version"></a>`cli_api_version`

Data type: `Any`

CLI config - API Version

Default value: `'v1'`

##### <a name="cli_debug"></a>`cli_debug`

Data type: `Any`

CLI config - Enable/Disable Debug

Default value: ``false``

##### <a name="cli_cache_token"></a>`cli_cache_token`

Data type: `Any`

CLI config - True to cache auth token until expries

Default value: ``true``

##### <a name="cli_username"></a>`cli_username`

Data type: `Any`

CLI config - Auth Username

Default value: `$st2::params::admin_username`

##### <a name="cli_password"></a>`cli_password`

Data type: `Any`

CLI config - Auth Password

Default value: `$st2::params::admin_password`

##### <a name="cli_apikey"></a>`cli_apikey`

Data type: `Any`

CLI config - StackStorm API Key to use for pack and k/v installation, instead of user/pass

Default value: ``undef``

##### <a name="cli_api_url"></a>`cli_api_url`

Data type: `Any`

CLI config - API URL

Default value: `"http://${st2::params::hostname}:${st2::params::api_port}"`

##### <a name="cli_auth_url"></a>`cli_auth_url`

Data type: `Any`

CLI config - Auth URL

Default value: `"http://${st2::params::hostname}:${st2::params::auth_port}"`

##### <a name="actionrunner_workers"></a>`actionrunner_workers`

Data type: `Any`

Set the number of actionrunner processes to start

Default value: `$st2::params::actionrunner_workers`

##### <a name="packs"></a>`packs`

Data type: `Any`

Hash of st2 packages to be installed

Default value: `{}`

##### <a name="packs_group"></a>`packs_group`

Data type: `Any`

Name of the group that will own the /opt/stackstorm/packs directory (default: st2packs)

Default value: `$st2::params::packs_group_name`

##### <a name="index_url"></a>`index_url`

Data type: `Any`

Url to the StackStorm Exchange index file. (default undef)

Default value: ``undef``

##### <a name="syslog"></a>`syslog`

Data type: `Any`

Routes all log messages to syslog

Default value: ``false``

##### <a name="syslog_host"></a>`syslog_host`

Data type: `Any`

Syslog host. Default: localhost

Default value: `'localhost'`

##### <a name="syslog_protocol"></a>`syslog_protocol`

Data type: `Any`

Syslog protocol. Default: udp

Default value: `'udp'`

##### <a name="syslog_port"></a>`syslog_port`

Data type: `Any`

Syslog port. Default: 514

Default value: `514`

##### <a name="syslog_facility"></a>`syslog_facility`

Data type: `Any`

Syslog facility. Default: local7

Default value: `'local7'`

##### <a name="ssh_key_location"></a>`ssh_key_location`

Data type: `Any`

Location on filesystem of Admin SSH key for remote runner

Default value: `'/home/stanley/.ssh/st2_stanley_key'`

##### <a name="db_host"></a>`db_host`

Data type: `Any`

Hostname to talk to st2 db

Default value: `$st2::params::hostname`

##### <a name="db_port"></a>`db_port`

Data type: `Any`

Port for db server for st2 to talk to

Default value: `$st2::params::mongodb_port`

##### <a name="db_bind_ips"></a>`db_bind_ips`

Data type: `Any`

Array of bind IP addresses for MongoDB to listen on

Default value: `$st2::params::mongodb_bind_ips`

##### <a name="db_name"></a>`db_name`

Data type: `Any`

Name of db to connect to (default: 'st2')

Default value: `$st2::params::mongodb_st2_db`

##### <a name="db_username"></a>`db_username`

Data type: `Any`

Username to connect to db with (default: 'stackstorm')

Default value: `$st2::params::mongodb_st2_username`

##### <a name="db_password"></a>`db_password`

Data type: `Any`

Password for 'admin' and 'stackstorm' users in MongDB.
If 'undef' then use $cli_password

Default value: `$st2::params::admin_password`

##### <a name="mongodb_version"></a>`mongodb_version`

Data type: `Any`

Version of MongoDB to install. If not provided it
will be auto-calcuated based on $version
(default: undef)

Default value: ``undef``

##### <a name="mongodb_manage_repo"></a>`mongodb_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories
for MongoDB (default: true)

Default value: ``true``

##### <a name="mongodb_auth"></a>`mongodb_auth`

Data type: `Any`

Boolean determining if auth should be enabled for
MongoDB. Note: On new versions of Puppet (4.0+)
you'll need to disable this setting.
(default: true)

Default value: ``true``

##### <a name="nginx_manage_repo"></a>`nginx_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories for nginx
(default: true)

Default value: ``true``

##### <a name="nginx_ssl_ciphers"></a>`nginx_ssl_ciphers`

Data type: `Any`

String or list of strings of acceptable SSL ciphers to configure nginx with.
@see http://nginx.org/en/docs/http/ngx_http_ssl_module.html
Note: the defaults are setup to restrict to TLSv1.2 and TLSv1.3 secure ciphers only
      (secure by default). The secure ciphers for each protocol were obtained via:
      @see https://wiki.mozilla.org/Security/Server_Side_TLS

Default value: `$st2::params::nginx_ssl_ciphers`

##### <a name="nginx_ssl_protocols"></a>`nginx_ssl_protocols`

Data type: `Any`

String or list of strings of acceptable SSL protocols to configure nginx with.
@see http://nginx.org/en/docs/http/ngx_http_ssl_module.html
Note: the defaults are setup to restrict to TLSv1.2 and TLSv1.3 only (secure by default)

Default value: `$st2::params::nginx_ssl_protocols`

##### <a name="nginx_ssl_port"></a>`nginx_ssl_port`

Data type: `Any`

What port should nginx listen on publicly for new connections (default: 443)

Default value: `$st2::params::nginx_ssl_port`

##### <a name="nginx_client_max_body_size"></a>`nginx_client_max_body_size`

Data type: `Any`

The maximum size of the body for a request allow through nginx.
We default this to '0' to allow for large messages/payloads/inputs/results
to be passed through nginx as is normal in the StackStorm context.
@see http://nginx.org/en/docs/http/ngx_http_core_module.html#client_max_body_size

Default value: `$st2::params::nginx_client_max_body_size`

##### <a name="web_root"></a>`web_root`

Data type: `Any`

Directory where the StackStorm WebUI site lives on the filesystem

Default value: `$st2::params::web_root`

##### <a name="timersengine_enabled"></a>`timersengine_enabled`

Data type: `Any`

Set to true if the st2timersengine service should be enabled
on this node (default: true)

Default value: `$st2::params::timersengine_enabled`

##### <a name="timersengine_timezone"></a>`timersengine_timezone`

Data type: `Any`

The local timezone for this node. (default: 'America/Los_Angeles')

Default value: `$st2::params::timersengine_timezone`

##### <a name="scheduler_sleep_interval"></a>`scheduler_sleep_interval`

Data type: `Any`

How long (in seconds) to sleep between each action
scheduler main loop run interval. (default = 0.1)

Default value: `$st2::params::scheduler_sleep_interval`

##### <a name="scheduler_gc_interval"></a>`scheduler_gc_interval`

Data type: `Any`

How often (in seconds) to look for zombie execution requests
before rescheduling them. (default = 10)

Default value: `$st2::params::scheduler_gc_interval`

##### <a name="scheduler_pool_size"></a>`scheduler_pool_size`

Data type: `Any`

The size of the pool used by the scheduler for scheduling
executions. (default = 10)

Default value: `$st2::params::scheduler_pool_size`

##### <a name="chatops_adapter"></a>`chatops_adapter`

Data type: `Any`

Adapter package(s) to be installed with npm. List of hashes.

Default value: `$st2::params::chatops_adapter`

##### <a name="chatops_adapter_conf"></a>`chatops_adapter_conf`

Data type: `Any`

Configuration parameters for Hubot adapter (hash)

Default value: `$st2::params::chatops_adapter_conf`

##### <a name="chatops_hubot_log_level"></a>`chatops_hubot_log_level`

Data type: `Any`

Logging level for hubot (string)

Default value: `$st2::params::hubot_log_level`

##### <a name="chatops_hubot_express_port"></a>`chatops_hubot_express_port`

Data type: `Any`

Port that hubot operates on (integer or string)

Default value: `$st2::params::hubot_express_port`

##### <a name="chatops_tls_cert_reject_unauthorized"></a>`chatops_tls_cert_reject_unauthorized`

Data type: `Any`

Should hubot validate SSL certs
Set to 1 when using self signed certs

Default value: `$st2::params::tls_cert_reject_unauthorized`

##### <a name="chatops_hubot_name"></a>`chatops_hubot_name`

Data type: `Any`

Name of the bot in chat. Should be
properly quoted if it has special characters,
example: '"MyBot!"'

Default value: `$st2::params::hubot_name`

##### <a name="chatops_hubot_alias"></a>`chatops_hubot_alias`

Data type: `Any`

Character to trigger the bot at the
beginning of a message. Must be properly
quoted of it's a special character,
example: "'!'"

Default value: `$st2::params::hubot_alias`

##### <a name="chatops_api_key"></a>`chatops_api_key`

Data type: `Any`

API key generated by `st2 apikey create`
that hubot will use to post data back
to StackStorm.
(default: undef)

Default value: ``undef``

##### <a name="chatops_st2_hostname"></a>`chatops_st2_hostname`

Data type: `Any`

Hostname of the StackStorm instance
that chatops will connect to for
API and Auth. If unspecified it will
use the default in /opt/stackstorm/chatops/st2chatops.env
(default: undef)

Default value: `$st2::params::hostname`

##### <a name="chatops_api_url"></a>`chatops_api_url`

Data type: `Any`

ChatOps config - API URL

Default value: `"https://${st2::params::hostname}/api"`

##### <a name="chatops_auth_url"></a>`chatops_auth_url`

Data type: `Any`

ChatOps config - Auth URL

Default value: `"https://${st2::params::hostname}/auth"`

##### <a name="chatops_web_url"></a>`chatops_web_url`

Data type: `Any`

Public URL of StackStorm instance.
used by chatops to offer links to
execution details in a chat.
If unspecified it will use the
default in /opt/stackstorm/chatops/st2chatops.env
(default: undef)

Default value: ``undef``

##### <a name="nodejs_version"></a>`nodejs_version`

Data type: `Any`

Version of NodeJS to install. If not provided it
will be auto-calcuated based on $version
(default: undef)

Default value: ``undef``

##### <a name="nodejs_manage_repo"></a>`nodejs_manage_repo`

Data type: `Any`

Set this to false when you have your own repositories
for NodeJS (default: true)

Default value: ``true``

##### <a name="redis_bind_ip"></a>`redis_bind_ip`

Data type: `Any`

Bind IP of the Redis server. Default is 127.0.0.1

Default value: `$st2::params::redis_bind_ip`

##### <a name="workflowengine_num"></a>`workflowengine_num`

Data type: `Any`

The number of workflowengines to have in an active active state (default: 1)

Default value: `$st2::params::workflowengine_num`

##### <a name="scheduler_num"></a>`scheduler_num`

Data type: `Any`

The number of schedulers to have in an active active state (default: 1)

Default value: `$st2::params::scheduler_num`

##### <a name="rulesengine_num"></a>`rulesengine_num`

Data type: `Any`

The number of rulesengines to have in an active active state (default: 1)

Default value: `$st2::params::rulesengine_num`

##### <a name="notifier_num"></a>`notifier_num`

Data type: `Any`

The number of notifiers to have in an active active state (default: 1)

Default value: `$st2::params::notifier_num`

##### <a name="erlang_url"></a>`erlang_url`

Data type: `Any`

The url for the erlang repositiory to be used for rabbitmq

Default value: `$st2::params::erlang_url`

##### <a name="erlang_key"></a>`erlang_key`

Data type: `Any`

The gpg key for the erlang repositiory to be used for rabbitmq

Default value: `$st2::params::erlang_key`

##### <a name="validate_output_schema"></a>`validate_output_schema`

Data type: `Any`

Enable/disable output schema validation in StackStorm

Default value: `$st2::params::validate_output_schema`

##### <a name="cli_silence_ssl_warnings"></a>`cli_silence_ssl_warnings`

Data type: `Any`



Default value: ``false``

##### <a name="ng_init"></a>`ng_init`

Data type: `Any`



Default value: ``true``

##### <a name="datastore_keys_dir"></a>`datastore_keys_dir`

Data type: `Any`



Default value: `$st2::params::datstore_keys_dir`

##### <a name="datastore_key_path"></a>`datastore_key_path`

Data type: `Any`



Default value: `"${st2::params::datstore_keys_dir}/datastore_key.json"`

##### <a name="rabbitmq_username"></a>`rabbitmq_username`

Data type: `Any`



Default value: `$st2::params::rabbitmq_username`

##### <a name="rabbitmq_password"></a>`rabbitmq_password`

Data type: `Any`



Default value: `$st2::params::rabbitmq_password`

##### <a name="rabbitmq_hostname"></a>`rabbitmq_hostname`

Data type: `Any`



Default value: `$st2::params::rabbitmq_hostname`

##### <a name="rabbitmq_port"></a>`rabbitmq_port`

Data type: `Any`



Default value: `$st2::params::rabbitmq_port`

##### <a name="rabbitmq_bind_ip"></a>`rabbitmq_bind_ip`

Data type: `Any`



Default value: `$st2::params::rabbitmq_bind_ip`

##### <a name="rabbitmq_vhost"></a>`rabbitmq_vhost`

Data type: `Any`



Default value: `$st2::params::rabbitmq_vhost`

##### <a name="redis_hostname"></a>`redis_hostname`

Data type: `Any`



Default value: `$st2::params::redis_hostname`

##### <a name="redis_port"></a>`redis_port`

Data type: `Any`



Default value: `$st2::params::redis_port`

##### <a name="redis_password"></a>`redis_password`

Data type: `Any`



Default value: `$st2::params::redis_password`

### <a name="st2auth"></a>`st2::auth`

StackStorn st2auth service provides a framework for authenticating with
various sources. Plugins to this framework that provide authentication
implementations are called 'backends'. This generic class can be used
to configure the st2auth service and also instantiate a proper backend.
The auth backend implementations are in the manifests/auth/ directory.

#### Examples

##### Basic usage (via st2)

```puppet
class { 'st2':
  auth_backend        => 'flat_file',
  auth_backend_config => {
    htpasswd_file => '/etc/something/htpasswd',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "flat_file"
st2::auth_backend_config"
  htpasswd_file: "/etc/something/htpasswd"
```

##### Direct usage (default Flat File auth backend)

```puppet
include st2::auth
```

##### Direct usage to configure a specific auth backend

```puppet
class { 'st2::auth':
  backend  => 'mongodb',
  backend_config => {
    db_host => 'mongodb.stackstorm.net',
  }
  use_ssl  => true,
  ssl_cert => '/etc/ssl/cert.crt',
  ssl_key  => '/etc/ssl/cert.key',
}
```

#### Parameters

The following parameters are available in the `st2::auth` class:

* [`backend`](#backend)
* [`backend_config`](#backend_config)
* [`debug`](#debug)
* [`mode`](#mode)
* [`use_ssl`](#use_ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)

##### <a name="backend"></a>`backend`

Data type: `Any`

Determines which auth backend to configure. (default: flat_file)
Available backends:
  * flat_file
  * keystone
  * ldap
  * mongodb
  * pam

Default value: `$st2::auth_backend`

##### <a name="backend_config"></a>`backend_config`

Data type: `Any`

Hash of parameters to pass to the backend class when it's instantiated.
This will be different for every backend.
Please see the corresponding backend class to determine what the config options should be.

Default value: `$st2::auth_backend_config`

##### <a name="debug"></a>`debug`

Data type: `Any`

Enable Debug (default: false)

Default value: `$st2::auth_debug`

##### <a name="mode"></a>`mode`

Data type: `Any`

Authentication mode, either 'standalone' or 'proxy' (default: standalone)

Default value: `$st2::auth_mode`

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Any`

Enable SSL (default: false)

Default value: `$st2::use_ssl`

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Any`

Path to SSL Certificate file (default: '/etc/ssl/st2/st2.crt')

Default value: `$st2::ssl_cert`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Any`

Path to SSL Key file (default: '/etc/ssl/st2/st2.key')

Default value: `$st2::ssl_key`

### <a name="st2authcommon"></a>`st2::auth::common`

Class that contains all of the "common" settings for auth.

* **Note** Don't use directly

#### Parameters

The following parameters are available in the `st2::auth::common` class:

* [`api_url`](#api_url)
* [`conf_file`](#conf_file)
* [`debug`](#debug)
* [`mode`](#mode)
* [`use_ssl`](#use_ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)

##### <a name="api_url"></a>`api_url`

Data type: `Any`

URL to the StackStorm API

Default value: `$st2::auth_api_url`

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="debug"></a>`debug`

Data type: `Any`

Enable Debug (default: false)

Default value: `$st2::auth_debug`

##### <a name="mode"></a>`mode`

Data type: `Any`

Authentication mode, either 'standalone' or 'proxy' (default: standalone)

Default value: `$st2::auth_mode`

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Any`

Enable SSL (default: false)

Default value: `$st2::use_ssl`

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Any`

Path to SSL Certificate file (default: '/etc/ssl/st2/st2.crt')

Default value: `$st2::ssl_cert`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Any`

Path to SSL Key file (default: '/etc/ssl/st2/st2.key')

Default value: `$st2::ssl_key`

### <a name="st2authflat_file"></a>`st2::auth::flat_file`

Auth class to configure and setup Flat File (htpasswd) Authentication

#### Examples

##### Instantiate via st2

```puppet
class { 'st2':
  auth_backend        => 'flat_file',
  auth_backend_config => {
    htpasswd_file => '/etc/something/htpasswd',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "flat_file"
st2::auth_backend_config"
  htpasswd_file: "/etc/something/htpasswd"
```

#### Parameters

The following parameters are available in the `st2::auth::flat_file` class:

* [`cli_username`](#cli_username)
* [`cli_password`](#cli_password)
* [`conf_file`](#conf_file)
* [`htpasswd_file`](#htpasswd_file)

##### <a name="cli_username"></a>`cli_username`

Data type: `Any`

CLI config - Auth Username

Default value: `$st2::cli_username`

##### <a name="cli_password"></a>`cli_password`

Data type: `Any`

CLI config - Auth Password

Default value: `$st2::cli_password`

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="htpasswd_file"></a>`htpasswd_file`

Data type: `Any`

Path to htpasswd file (default: /etc/st2/htpasswd)

Default value: `$st2::params::auth_htpasswd_file`

### <a name="st2authkeystone"></a>`st2::auth::keystone`

For information on parameters see the
{backend documentation}[https://github.com/StackStorm/st2-auth-backend-keystone#configuration-options]

#### Examples

##### Instantiate via st2

```puppet
class { 'st2':
  auth_backend        => 'keystone',
  auth_backend_config => {
    keystone_url     => 'http://keystone.domain.tld:5000',
    keystone_version => '3',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "keystone"
st2::auth_backend_config:
  keystone_url: "http://keystone.domain.tld:5000"
  keystone_version: "3"
```

#### Parameters

The following parameters are available in the `st2::auth::keystone` class:

* [`conf_file`](#conf_file)
* [`keystone_url`](#keystone_url)
* [`keystone_version`](#keystone_version)

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="keystone_url"></a>`keystone_url`

Data type: `Any`

Keystone URL to connect to (default: '127.0.0.1')

Default value: `'http://127.0.0.1:5000'`

##### <a name="keystone_version"></a>`keystone_version`

Data type: `Any`

Keystone API version (default: '2')

Default value: `'2'`

### <a name="st2authldap"></a>`st2::auth::ldap`

For information on parameters see the
{backend documentation}[https://docs.stackstorm.com/authentication.html#ldap]

#### Examples

##### Instantiate via st2 (Active Directory)

```puppet
class { 'st2':
  auth_backend        => 'ldap',
  auth_backend_config => {
    host            => 'ldap.domain.tld',
    bind_dn         => 'cn=ldap_stackstorm,ou=service accounts,dc=domain,dc=tld',
    base_dn         => 'dc=domain,dc=tld',
    scope           => 'subtree',
    id_attr         => 'username',
    bind_pw         => 'some_password',
    group_dns       => ['"cn=stackstorm_users,ou=groups,dc=domain,dc=tld"'],
    account_pattern => 'userPrincipalName={username}',
  },
}
```

##### Instantiate via Hiera (Active Directory)

```puppet
st2::auth_backend: "ldap"
st2::auth_backend_config:
  host: "ldaps.domain.tld"
  use_tls: false
  use_ssl: true
  port: 636
  bind_dn: 'cn=ldap_stackstorm,ou=service accounts,dc=domain,dc=tld'
  bind_pw: 'some_password'
  chase_referrals: false
  base_dn: 'dc=domain,dc=tld'
  group_dns:
    - '"cn=stackstorm_users,ou=groups,dc=domain,dc=tld"'
  scope: "subtree"
  id_attr: "username"
  account_pattern: "userPrincipalName={username}"
```

#### Parameters

The following parameters are available in the `st2::auth::ldap` class:

* [`conf_file`](#conf_file)
* [`host`](#host)
* [`use_tls`](#use_tls)
* [`use_ssl`](#use_ssl)
* [`port`](#port)
* [`bind_dn`](#bind_dn)
* [`bind_pw`](#bind_pw)
* [`base_dn`](#base_dn)
* [`group_dns`](#group_dns)
* [`chase_referrals`](#chase_referrals)
* [`scope`](#scope)
* [`id_attr`](#id_attr)
* [`account_pattern`](#account_pattern)
* [`group_pattern`](#group_pattern)

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="host"></a>`host`

Data type: `Any`

URI of the LDAP server.
Format: <code><protocol>://<hostname>[:port]</code> (protocol: ldap or ldaps)

Default value: `''`

##### <a name="use_tls"></a>`use_tls`

Data type: `Any`

Boolean parameter to set if tls is required.
Should be set to false using ldaps in the uri. (default: false)

Default value: ``false``

##### <a name="use_ssl"></a>`use_ssl`

Data type: `Any`

Boolean parameter to set if ssl is required.
Should be set to true using ldaps in the uri. (default: false)

Default value: ``false``

##### <a name="port"></a>`port`

Data type: `Any`

Integer port to be used for LDAP connection
Should be set to false using ldaps in the uri. (default: 389)

Default value: `389`

##### <a name="bind_dn"></a>`bind_dn`

Data type: `Any`

DN user to bind to LDAP. If an empty string, an anonymous bind is performed.
To use the user supplied username in the bind_dn, use the <code>{username}</code> placeholder
in string.

Default value: `''`

##### <a name="bind_pw"></a>`bind_pw`

Data type: `Any`

DN password. Use the <code>{password}</code> placeholder in the string to use the user supplied password.

Default value: `''`

##### <a name="base_dn"></a>`base_dn`

Data type: `Any`

Base DN to search for all users/groups entries.

Default value: `''`

##### <a name="group_dns"></a>`group_dns`

Data type: `Any`

DN of groups user must be member of to be granted access

Default value: ``undef``

##### <a name="chase_referrals"></a>`chase_referrals`

Data type: `Any`

Boolean parameter to set whether to chase referrals. (default: true)

Default value: ``true``

##### <a name="scope"></a>`scope`

Data type: `Any`

Search scope (base, onelevel, or subtree) (default: subtree)

Default value: `'subtree'`

##### <a name="id_attr"></a>`id_attr`

Data type: `Any`

Field name of the user ID attribute (default: uid)

Default value: `'uid'`

##### <a name="account_pattern"></a>`account_pattern`

Data type: `Any`

LDAP subtree pattern to match user. The user’s username is escaped and interpolated into this string

Default value: ``undef``

##### <a name="group_pattern"></a>`group_pattern`

Data type: `Any`

LDAP subtree pattern for user groups. Both user_dn and username are escaped and then interpolated into this string

Default value: ``undef``

### <a name="st2authmongodb"></a>`st2::auth::mongodb`

For information on parameters see the
{backend documentation}[https://github.com/StackStorm/st2-auth-backend-mongodb#configuration-options]

#### Examples

##### Instantiate via st2

```puppet
class { 'st2':
  auth_backend        => 'mongodb',
  auth_backend_config => {
    db_host => 'mongodb.stackstorm.net',
    db_port => '1234',
    db_name => 'myauthdb',
  },
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "mongodb"
st2::auth_backend_config:
  db_host: "mongodb.stackstorm.net"
  db_port: "1234"
  db_name: "myauthdb"
```

#### Parameters

The following parameters are available in the `st2::auth::mongodb` class:

* [`conf_file`](#conf_file)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_auth`](#db_auth)
* [`db_username`](#db_username)
* [`db_password`](#db_password)

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="db_host"></a>`db_host`

Data type: `Any`

Hostname for the MongoDB server (default: 127.0.0.1)

Default value: `$st2::db_host`

##### <a name="db_port"></a>`db_port`

Data type: `Any`

Port for the MongoDB server (default: 27017)

Default value: `$st2::db_port`

##### <a name="db_name"></a>`db_name`

Data type: `Any`

Database name in MongoDB (default: st2auth)

Default value: `'st2auth'`

##### <a name="db_auth"></a>`db_auth`

Data type: `Any`

Enable authentication with MongoDB (required for MongoDB installs with auth enabled)

Default value: `$st2::mongodb_auth`

##### <a name="db_username"></a>`db_username`

Data type: `Any`

Username for MongoDB login (default: st2auth)

Default value: `$st2::db_username`

##### <a name="db_password"></a>`db_password`

Data type: `Any`

Password for MongoDB login (default: st2auth)

Default value: `$st2::db_password`

### <a name="st2authpam"></a>`st2::auth::pam`

Auth class to configure and setup PAM authentication.

* **TODO** Need to configure st2auth service to run as root

* **Note** This backend will NOT allow you to auth with PAM for the 'root' user.
You will need to auth a non-root user on the Linux host.

#### Examples

##### Instantiate via st2

```puppet
class { 'st2':
  backend => 'pam',
}
```

##### Instantiate via Hiera

```puppet
st2::auth_backend: "pam"
st2::auth_backend_config: {}
```

#### Parameters

The following parameters are available in the `st2::auth::pam` class:

* [`conf_file`](#conf_file)

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

### <a name="st2kvs"></a>`st2::kvs`

Automatically loads Key/Value pairs for StackStorm DB from Hiera

* **See also**
  * st2::kv

#### Examples

##### Key/value pairs defined in Hiera

```puppet
st2::kvs:
  keyname:
    value: 'blah'
  mysupercoolkey:
    value: 'xyz123'
```

### <a name="st2loggingrsyslog"></a>`st2::logging::rsyslog`

This class bootstraps a system configured with rsyslog
and st2::syslog enabled to route messages to all the right
places.

#### Examples

##### Basic usage

```puppet
include st2::logging::rsyslog
```

### <a name="st2notices"></a>`st2::notices`

This is a private class used to store long strings to limit down on lint problems.

* **Note** Please do not call directly

### <a name="st2notifier"></a>`st2::notifier`

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2notifier</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
  * https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample

#### Examples

##### Basic usage

```puppet
include st2::notifier
```

#### Parameters

The following parameters are available in the `st2::notifier` class:

* [`notifier_num`](#notifier_num)
* [`notifier_services`](#notifier_services)

##### <a name="notifier_num"></a>`notifier_num`

Data type: `Any`

The number of notifiers to have in an active active state

Default value: `$st2::notifier_num`

##### <a name="notifier_services"></a>`notifier_services`

Data type: `Any`

Name of all the notifier services

Default value: `$st2::params::notifier_services`

### <a name="st2packs"></a>`st2::packs`

Install and configure st2 packages in bulk and via Hiera.

* **See also**
  * st2::pack
    * and st2::pack::config for usage

#### Examples

##### Basic Usage

```puppet
class { 'st2::packs':
  packs => {
    puppet => {},
    influxdb => {
      config => {
        server => 'influxdb.domain.tld',
    },
  },
}
```

##### Created via Hiera

```puppet
st2::packs:
  puppet: {}
  influxdb:
    config:
      server => 'influxdb.domain.tld'
```

#### Parameters

The following parameters are available in the `st2::packs` class:

* [`packs`](#packs)

##### <a name="packs"></a>`packs`

Data type: `Any`



Default value: `$st2::packs`

### <a name="st2params"></a>`st2::params`

Main parameters to manage the st2 module

#### Examples

##### Best Practice

```puppet
class { 'st2::params':
  admin_username => 'myuser',
  admin_password => 'SuperSecret!',
}
include st2::profile::fullinstall
```

#### Parameters

The following parameters are available in the `st2::params` class:

* [`packs_group_name`](#packs_group_name)
* [`hostname`](#hostname)
* [`admin_username`](#admin_username)
* [`admin_password`](#admin_password)

##### <a name="packs_group_name"></a>`packs_group_name`

Data type: `Any`

The name of the group created to hold the st2 admin user

Default value: `'st2packs'`

##### <a name="hostname"></a>`hostname`

Data type: `Any`

Hostname of the StackStorm box. This is used as the default to drive a lot of
other parameters in the st2 class such as auth URL, MongoDB host, RabbitMQ host, etc.

Default value: `'127.0.0.1'`

##### <a name="admin_username"></a>`admin_username`

Data type: `Any`

Username of the StackStorm admin user. Best practice is to change this to a unique username.

Default value: `'st2admin'`

##### <a name="admin_password"></a>`admin_password`

Data type: `Any`

Password of the StackStorm admin user. Best practice is to change this to a unique password.

Default value: `'Ch@ngeMe'`

### <a name="st2profilechatops"></a>`st2::profile::chatops`

Profile to install and configure chatops for st2

* **Note** This class doesn't need to be invoked directly, instead it's best to customize
it through the main +st2+ class

#### Examples

##### Basic Usage

```puppet
class { 'st2':
  chatops_hubot_name => '"@RosieRobot"',
  chatops_api_key    => '"xxxxyyyyy123abc"',
  chatops_adapter    => {
    hubot-adapter => {
      package => 'hubot-rocketchat',
      source  => 'git+ssh://git@git.company.com:npm/hubot-rocketchat#master',
    },
  },
  chatops_adapter_conf => {
    HUBOT_ADAPTER        => 'rocketchat',
    ROCKETCHAT_URL       => 'https://chat.company.com',
    ROCKETCHAT_ROOM      => 'stackstorm',
    LISTEN_ON_ALL_PUBLIC => 'true',
    ROCKETCHAT_USER      => 'st2',
    ROCKETCHAT_PASSWORD  => 'secret123',
    ROCKETCHAT_AUTH      => 'password',
    RESPOND_TO_DM        => 'true',
  },
}
```

#### Parameters

The following parameters are available in the `st2::profile::chatops` class:

* [`version`](#version)
* [`hubot_log_level`](#hubot_log_level)
* [`hubot_express_port`](#hubot_express_port)
* [`tls_cert_reject_unauthorized`](#tls_cert_reject_unauthorized)
* [`hubot_name`](#hubot_name)
* [`hubot_alias`](#hubot_alias)
* [`npm_packages`](#npm_packages)
* [`adapter_config`](#adapter_config)
* [`api_key`](#api_key)
* [`st2_hostname`](#st2_hostname)
* [`web_url`](#web_url)
* [`api_url`](#api_url)
* [`auth_url`](#auth_url)
* [`auth_username`](#auth_username)
* [`auth_password`](#auth_password)

##### <a name="version"></a>`version`

Data type: `Any`

Version of the st2chatops package to install

Default value: `$st2::version`

##### <a name="hubot_log_level"></a>`hubot_log_level`

Data type: `Any`

Hubot log level

Default value: `$st2::chatops_hubot_log_level`

##### <a name="hubot_express_port"></a>`hubot_express_port`

Data type: `Any`

Express port hubot listens to

Default value: `$st2::chatops_hubot_express_port`

##### <a name="tls_cert_reject_unauthorized"></a>`tls_cert_reject_unauthorized`

Data type: `Any`

Set to 1 when using self signed certs

Default value: `$st2::chatops_tls_cert_reject_unauthorized`

##### <a name="hubot_name"></a>`hubot_name`

Data type: `Any`

Name of the bot in chat. Should be properly quoted if it has special characters,
example: '"MyBot!"'

Default value: `$st2::chatops_hubot_name`

##### <a name="hubot_alias"></a>`hubot_alias`

Data type: `Any`

Character to trigger the bot at the beginning of a message. Must be properly
quoted of it's a special character, example: "'!'"

Default value: `$st2::chatops_hubot_alias`

##### <a name="npm_packages"></a>`npm_packages`

Data type: `Any`

NodeJS packages to be installed (usually a hubot adapter)

Default value: `$st2::chatops_adapter`

##### <a name="adapter_config"></a>`adapter_config`

Data type: `Any`

Configuration parameters for Hubot adapter (hash)

Default value: `$st2::chatops_adapter_conf`

##### <a name="api_key"></a>`api_key`

Data type: `Any`

API key generated by <code>st2 apikey create</code> that hubot will use to post data back
to StackStorm.

Default value: `$st2::chatops_api_key`

##### <a name="st2_hostname"></a>`st2_hostname`

Data type: `Any`

Hostname of the StackStorm instance that chatops will connect to for API and Auth.
If unspecified it will use the default in <code>/opt/stackstorm/chatops/st2chatops.env</code>

Default value: `$st2::chatops_st2_hostname`

##### <a name="web_url"></a>`web_url`

Data type: `Any`

Public URL of StackStorm instance. Used by chatops to offer links to execution details in a chat.
If unspecified it will use the default in <code>/opt/stackstorm/chatops/st2chatops.env</code>

Default value: `$st2::chatops_web_url`

##### <a name="api_url"></a>`api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: `$st2::chatops_api_url`

##### <a name="auth_url"></a>`auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: `$st2::chatops_auth_url`

##### <a name="auth_username"></a>`auth_username`

Data type: `Any`

StackStorm auth Username for ChatOps to communicate back with StackStorm.
Used if +api_key+ is not specified (optional)

Default value: `$st2::cli_username`

##### <a name="auth_password"></a>`auth_password`

Data type: `Any`

StackStorm auth Password for ChatOps to communicate back with StackStorm.
Used if +api_key+ is not specified (optional)

Default value: `$st2::cli_password`

### <a name="st2profileclient"></a>`st2::profile::client`

Profile to install, configure and manage all client libraries for st2

#### Examples

##### Basic Usage

```puppet
include st2::profile::client
```

#### Parameters

The following parameters are available in the `st2::profile::client` class:

* [`auth`](#auth)
* [`api_url`](#api_url)
* [`auth_url`](#auth_url)
* [`base_url`](#base_url)
* [`username`](#username)
* [`password`](#password)
* [`api_version`](#api_version)
* [`cacert`](#cacert)
* [`debug`](#debug)
* [`cache_token`](#cache_token)
* [`silence_ssl_warnings`](#silence_ssl_warnings)

##### <a name="auth"></a>`auth`

Data type: `Any`

Is auth enabled or not.

Default value: `$st2::auth`

##### <a name="api_url"></a>`api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: `$st2::cli_api_url`

##### <a name="auth_url"></a>`auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: `$st2::cli_auth_url`

##### <a name="base_url"></a>`base_url`

Data type: `Any`

Base URL for other StackStorm services

Default value: `$st2::cli_base_url`

##### <a name="username"></a>`username`

Data type: `Any`

Username for auth on the CLI

Default value: `$st2::cli_username`

##### <a name="password"></a>`password`

Data type: `Any`

Password for auth on the CLI

Default value: `$st2::cli_password`

##### <a name="api_version"></a>`api_version`

Data type: `Any`

Version of the StackStorm API

Default value: `$st2::cli_api_version`

##### <a name="cacert"></a>`cacert`

Data type: `Any`

Path to the SSL CA certficate for the StackStorm services

Default value: `$st2::cli_cacert`

##### <a name="debug"></a>`debug`

Data type: `Any`

Enable debug mode

Default value: `$st2::cli_debug`

##### <a name="cache_token"></a>`cache_token`

Data type: `Any`

Enable cacheing authentication tokens until they expire

Default value: `$st2::cli_cache_token`

##### <a name="silence_ssl_warnings"></a>`silence_ssl_warnings`

Data type: `Any`

Enable silencing SSL warnings for self-signed certs

Default value: `$st2::cli_silence_ssl_warnings`

### <a name="st2profilefacter"></a>`st2::profile::facter`

Setup custom fact locations

#### Examples

##### Basic Usage

```puppet
include st2::profile::facter
```

### <a name="st2profilefullinstall"></a>`st2::profile::fullinstall`

Components:
 * RabbitMQ
 * Python
 * MongoDB
 * NodeJS
 * nginx

#### Examples

##### Basic Usage

```puppet
include st2::profile::fullinstall
```

##### Customizing parameters

```puppet
# Customizations are done via the main st2 class
class { 'st2':
  # ... assign custom parameters
}

include st2::profile::fullinstall
```

### <a name="st2profilemongodb"></a>`st2::profile::mongodb`

StackStorm compatable installation of MongoDB and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::mongodb
```

##### Customize (done via st2)

```puppet
class { 'st2':
  db_name     => 'stackstormdb',
  db_username => 'abc',
  db_password => 'xyz123',
  db_port     => 12345,
}
include st2::profile::mongodb
```

#### Parameters

The following parameters are available in the `st2::profile::mongodb` class:

* [`db_name`](#db_name)
* [`db_username`](#db_username)
* [`db_password`](#db_password)
* [`db_port`](#db_port)
* [`db_bind_ips`](#db_bind_ips)
* [`version`](#version)
* [`manage_repo`](#manage_repo)
* [`auth`](#auth)

##### <a name="db_name"></a>`db_name`

Data type: `Any`

Name of the StackStorm database

Default value: `$st2::db_name`

##### <a name="db_username"></a>`db_username`

Data type: `Any`

Username to connect to db with

Default value: `$st2::db_username`

##### <a name="db_password"></a>`db_password`

Data type: `Any`

Password for 'admin' and 'stackstorm' users in MongDB. If 'undef' then use $cli_password

Default value: `$st2::db_password`

##### <a name="db_port"></a>`db_port`

Data type: `Any`

Port for db server for st2 to talk to

Default value: `$st2::db_port`

##### <a name="db_bind_ips"></a>`db_bind_ips`

Data type: `Any`

Array of bind IP addresses for MongoDB to listen on

Default value: `$st2::db_bind_ips`

##### <a name="version"></a>`version`

Data type: `Any`

Version of MongoDB to install. If not provided it will be auto-calcuated based on $st2::version.

Default value: `$st2::mongodb_version`

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Any`

Set this to +false+ when you have your own repositories for mongodb

Default value: `$st2::mongodb_manage_repo`

##### <a name="auth"></a>`auth`

Data type: `Any`

Boolean determining if auth should be enabled for MongoDB.

Default value: `$st2::mongodb_auth`

### <a name="st2profilenginx"></a>`st2::profile::nginx`

StackStorm compatible installation of nginx and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::nginx
```

##### Disable managing the nginx repo so you can manage it yourself

```puppet
class { 'st2::profile::nginx':
  manage_repo => false,
}
```

#### Parameters

The following parameters are available in the `st2::profile::nginx` class:

* [`manage_repo`](#manage_repo)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Any`

Set this to false when you have your own repository for nginx

Default value: `$st2::nginx_manage_repo`

### <a name="st2profilenodejs"></a>`st2::profile::nodejs`

This class is needed for StackStorm ChatOps +st2::profile::chatops::.
Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>NodeJS</code> installation on a single node.

#### Examples

##### Basic Usage

```puppet
include st2::profile::nodejs
```

##### Custom Parameters

```puppet
class { 'st2::profile::nodejs':
}
```

#### Parameters

The following parameters are available in the `st2::profile::nodejs` class:

* [`manage_repo`](#manage_repo)
* [`version`](#version)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Any`

Set this to false when you have your own repositories for NodeJS.

Default value: `$st2::nodejs_manage_repo`

##### <a name="version"></a>`version`

Data type: `Any`

Version of NodeJS to install. If not provided it will be auto-calcuated based on $st2::version

Default value: `$st2::nodejs_version`

### <a name="st2profilepython"></a>`st2::profile::python`

include st2::profile::python

#### Examples

##### Basic Usage

```puppet
include st2::profile::python
```

##### Install with python 3.8 (if not default on your system)

```puppet
$st2_python_version = $facts['os']['family'] ? {
  'RedHat' => '3.8',
  'Debian' => 'python3.8',
}
class { 'st2':
  python_version            => $st2_python_version,
}
```

#### Parameters

The following parameters are available in the `st2::profile::python` class:

* [`version`](#version)

##### <a name="version"></a>`version`

Data type: `String`

Version of Python to install. Default is 'system' meaning the system version
of Python will be used.
To install Python 3.8 on RHEL/CentOS/Rocky 7/8 specify '3.8'.
To install Python 3.8 on Ubuntu 18.04/20.04 specify 'python3.8'.

Default value: `$st2::python_version`

### <a name="st2profilerabbitmq"></a>`st2::profile::rabbitmq`

StackStorm compatable installation of RabbitMQ and dependencies.

#### Examples

##### Basic Usage

```puppet
include st2::profile::rabbitmq
```

##### Authentication enabled (configured vi st2)

```puppet
class { 'st2':
  rabbitmq_username => 'rabbitst2',
  rabbitmq_password => 'secret123',
}
include st2::profile::rabbitmq
```

#### Parameters

The following parameters are available in the `st2::profile::rabbitmq` class:

* [`username`](#username)
* [`password`](#password)
* [`port`](#port)
* [`bind_ip`](#bind_ip)
* [`vhost`](#vhost)
* [`erlang_url`](#erlang_url)
* [`erlang_key`](#erlang_key)

##### <a name="username"></a>`username`

Data type: `Any`

User to create within RabbitMQ for authentication.

Default value: `$st2::rabbitmq_username`

##### <a name="password"></a>`password`

Data type: `Any`

Password of +username+ for RabbitMQ authentication.

Default value: `$st2::rabbitmq_password`

##### <a name="port"></a>`port`

Data type: `Any`

Port to bind to for the RabbitMQ server

Default value: `$st2::rabbitmq_port`

##### <a name="bind_ip"></a>`bind_ip`

Data type: `Any`

IP address to bind to for the RabbitMQ server

Default value: `$st2::rabbitmq_bind_ip`

##### <a name="vhost"></a>`vhost`

Data type: `Any`

RabbitMQ virtual host to create for StackStorm

Default value: `$st2::rabbitmq_vhost`

##### <a name="erlang_url"></a>`erlang_url`

Data type: `Any`



Default value: `$st2::erlang_url`

##### <a name="erlang_key"></a>`erlang_key`

Data type: `Any`



Default value: `$st2::erlang_key`

### <a name="st2profileredis"></a>`st2::profile::redis`

StackStorm compatable installation of Redis.

#### Examples

##### Basic Usage

```puppet
include st2::profile::redis
```

##### Install with redis

```puppet
class { '::redis':
   bind_ip => '127.0.0.1',
 }
```

#### Parameters

The following parameters are available in the `st2::profile::redis` class:

* [`bind_ip`](#bind_ip)

##### <a name="bind_ip"></a>`bind_ip`

Data type: `String`

Bind IP of the Redis server. Default is 127.0.0.1

Default value: `$st2::redis_bind_ip`

### <a name="st2profileselinux"></a>`st2::profile::selinux`

Configure SELinux so that StackStorm services run properly

#### Examples

##### Basic Usage

```puppet
include st2::profile::selinux
```

### <a name="st2profileserver"></a>`st2::profile::server`

Profile to install, configure and manage all server components for st2

#### Examples

##### Basic usage

```puppet
include st2::profile::server
```

#### Parameters

The following parameters are available in the `st2::profile::server` class:

* [`version`](#version)
* [`conf_dir`](#conf_dir)
* [`conf_file`](#conf_file)
* [`auth`](#auth)
* [`actionrunner_workers`](#actionrunner_workers)
* [`st2api_listen_ip`](#st2api_listen_ip)
* [`st2api_listen_port`](#st2api_listen_port)
* [`st2auth_listen_ip`](#st2auth_listen_ip)
* [`st2auth_listen_port`](#st2auth_listen_port)
* [`syslog`](#syslog)
* [`syslog_host`](#syslog_host)
* [`syslog_protocol`](#syslog_protocol)
* [`syslog_port`](#syslog_port)
* [`syslog_facility`](#syslog_facility)
* [`ssh_key_location`](#ssh_key_location)
* [`db_username`](#db_username)
* [`db_password`](#db_password)
* [`index_url`](#index_url)
* [`ng_init`](#ng_init)
* [`rabbitmq_username`](#rabbitmq_username)
* [`rabbitmq_password`](#rabbitmq_password)
* [`rabbitmq_hostname`](#rabbitmq_hostname)
* [`rabbitmq_port`](#rabbitmq_port)
* [`rabbitmq_vhost`](#rabbitmq_vhost)
* [`redis_hostname`](#redis_hostname)
* [`redis_port`](#redis_port)
* [`redis_password`](#redis_password)
* [`packs_group`](#packs_group)
* [`validate_output_schema`](#validate_output_schema)

##### <a name="version"></a>`version`

Data type: `Any`

Version of StackStorm to install

Default value: `$st2::version`

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Any`

The directory where st2 configs are stored

Default value: `$st2::conf_dir`

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="auth"></a>`auth`

Data type: `Any`

Toggle Auth

Default value: `$st2::auth`

##### <a name="actionrunner_workers"></a>`actionrunner_workers`

Data type: `Any`

Set the number of actionrunner processes to start

Default value: `$st2::actionrunner_workers`

##### <a name="st2api_listen_ip"></a>`st2api_listen_ip`

Data type: `Any`

Listen IP for st2api process

Default value: `'127.0.0.1'`

##### <a name="st2api_listen_port"></a>`st2api_listen_port`

Data type: `Any`

Listen port for st2api process

Default value: `'9101'`

##### <a name="st2auth_listen_ip"></a>`st2auth_listen_ip`

Data type: `Any`

Listen IP for st2auth process

Default value: `'127.0.0.1'`

##### <a name="st2auth_listen_port"></a>`st2auth_listen_port`

Data type: `Any`

Listen port for st2auth process

Default value: `'9100'`

##### <a name="syslog"></a>`syslog`

Data type: `Any`

Routes all log messages to syslog

Default value: `$st2::syslog`

##### <a name="syslog_host"></a>`syslog_host`

Data type: `Any`

Syslog host.

Default value: `$st2::syslog_host`

##### <a name="syslog_protocol"></a>`syslog_protocol`

Data type: `Any`

Syslog protocol.

Default value: `$st2::syslog_protocol`

##### <a name="syslog_port"></a>`syslog_port`

Data type: `Any`

Syslog port.

Default value: `$st2::syslog_port`

##### <a name="syslog_facility"></a>`syslog_facility`

Data type: `Any`

Syslog facility.

Default value: `$st2::syslog_facility`

##### <a name="ssh_key_location"></a>`ssh_key_location`

Data type: `Any`

Location on filesystem of Admin SSH key for remote runner

Default value: `$st2::ssh_key_location`

##### <a name="db_username"></a>`db_username`

Data type: `Any`

Username to connect to MongoDB with (default: 'stackstorm')

Default value: `$st2::db_username`

##### <a name="db_password"></a>`db_password`

Data type: `Any`

Password for 'stackstorm' user in MongDB.

Default value: `$st2::db_password`

##### <a name="index_url"></a>`index_url`

Data type: `Any`

Url to the StackStorm Exchange index file. (default undef)

Default value: `$st2::index_url`

##### <a name="ng_init"></a>`ng_init`

Data type: `Any`



Default value: `$st2::ng_init`

##### <a name="rabbitmq_username"></a>`rabbitmq_username`

Data type: `Any`



Default value: `$st2::rabbitmq_username`

##### <a name="rabbitmq_password"></a>`rabbitmq_password`

Data type: `Any`



Default value: `$st2::rabbitmq_password`

##### <a name="rabbitmq_hostname"></a>`rabbitmq_hostname`

Data type: `Any`



Default value: `$st2::rabbitmq_hostname`

##### <a name="rabbitmq_port"></a>`rabbitmq_port`

Data type: `Any`



Default value: `$st2::rabbitmq_port`

##### <a name="rabbitmq_vhost"></a>`rabbitmq_vhost`

Data type: `Any`



Default value: `$st2::rabbitmq_vhost`

##### <a name="redis_hostname"></a>`redis_hostname`

Data type: `Any`



Default value: `$st2::redis_hostname`

##### <a name="redis_port"></a>`redis_port`

Data type: `Any`



Default value: `$st2::redis_port`

##### <a name="redis_password"></a>`redis_password`

Data type: `Any`



Default value: `$st2::redis_password`

##### <a name="packs_group"></a>`packs_group`

Data type: `Any`



Default value: `$st2::packs_group_name`

##### <a name="validate_output_schema"></a>`validate_output_schema`

Data type: `Any`



Default value: `$st2::validate_output_schema`

### <a name="st2profileweb"></a>`st2::profile::web`

Profile to install, configure and manage StackStorm web UI (st2web).

#### Examples

##### Basic Usage

```puppet
include st2::profile::web'
```

##### Managing your own certificate

```puppet
# create your own certificate and key in the correct locations
file { '/etc/ssl/st2/st2.crt':
  content => 'my cert data',
}
file { '/etc/ssl/st2/st2.key':
  content => 'my privatekey data',
}

# instantiate this profile with ssl_cert_manage false
class { 'st2::profile::web':
  ssl_cert_manage => false,
}
```

##### Change the SSL protocols and ciphers

```puppet
class { 'st2::profile::web':
  nginx_ssl_protocols => ['TLSv1.2'],
  nginx_ssl_ciphers => [
    'ECDHE-ECDSA-AES256-GCM-SHA384',
    'ECDHE-ECDSA-AES256-SHA384',
  ],
}
```

#### Parameters

The following parameters are available in the `st2::profile::web` class:

* [`nginx_ssl_ciphers`](#nginx_ssl_ciphers)
* [`nginx_ssl_protocols`](#nginx_ssl_protocols)
* [`nginx_ssl_port`](#nginx_ssl_port)
* [`nginx_client_max_body_size`](#nginx_client_max_body_size)
* [`ssl_cert_manage`](#ssl_cert_manage)
* [`ssl_dir`](#ssl_dir)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`version`](#version)
* [`web_root`](#web_root)

##### <a name="nginx_ssl_ciphers"></a>`nginx_ssl_ciphers`

Data type: `Variant[Array[String], String]`

String or list of strings of acceptable SSL ciphers to configure nginx with.
@see http://nginx.org/en/docs/http/ngx_http_ssl_module.html
Note: the defaults are setup to restrict to TLSv1.2 and TLSv1.3 secure ciphers only
      (secure by default). The secure ciphers for each protocol were obtained via:
      @see https://wiki.mozilla.org/Security/Server_Side_TLS

Default value: `$st2::nginx_ssl_ciphers`

##### <a name="nginx_ssl_protocols"></a>`nginx_ssl_protocols`

Data type: `Variant[Array[String], String]`

String or list of strings of acceptable SSL protocols to configure nginx with.
@see http://nginx.org/en/docs/http/ngx_http_ssl_module.html
Note: the defaults are setup to restrict to TLSv1.2 and TLSv1.3 only (secure by default)

Default value: `$st2::nginx_ssl_protocols`

##### <a name="nginx_ssl_port"></a>`nginx_ssl_port`

Data type: `Stdlib::Port`

What port should nginx listen on publicly for new connections (default: 443)

Default value: `$st2::nginx_ssl_port`

##### <a name="nginx_client_max_body_size"></a>`nginx_client_max_body_size`

Data type: `String`

The maximum size of the body for a request allow through nginx.
We default this to '0' to allow for large messages/payloads/inputs/results
to be passed through nginx as is normal in the StackStorm context.
@see http://nginx.org/en/docs/http/ngx_http_core_module.html#client_max_body_size

Default value: `$st2::nginx_client_max_body_size`

##### <a name="ssl_cert_manage"></a>`ssl_cert_manage`

Data type: `Boolean`

Boolean to determine if this module should manage the SSL certificate used by nginx.

Default value: `$st2::ssl_cert_manage`

##### <a name="ssl_dir"></a>`ssl_dir`

Data type: `Stdlib::Absolutepath`

Directory where st2web will look for its SSL info.
(default: /etc/ssl/st2)

Default value: `$st2::ssl_dir`

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `String`

Path to the file where the StackStorm SSL cert will
be generated. (default: /etc/ssl/st2/st2.crt)

Default value: `$st2::ssl_cert`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `String`

Path to the file where the StackStorm SSL key will
be generated. (default: /etc/ssl/st2/st2.key)

Default value: `$st2::ssl_key`

##### <a name="version"></a>`version`

Data type: `String`

Version of StackStorm WebUI to install

Default value: `$st2::version`

##### <a name="web_root"></a>`web_root`

Data type: `String`

Directory where the StackStorm WebUI site lives on the filesystem

Default value: `$st2::web_root`

### <a name="st2repo"></a>`st2::repo`

Manages the installation of st2 required repos for installing the StackStorm packages.

#### Examples

##### Basic usage

```puppet
include st2::repo
```

##### Installing from unstable

```puppet
class { 'st2::repo':
  repository => 'unstable',
}
```

#### Parameters

The following parameters are available in the `st2::repo` class:

* [`ensure`](#ensure)
* [`repository`](#repository)
* [`manage_epel_repo`](#manage_epel_repo)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

The basic state the repo should be in

Default value: `'present'`

##### <a name="repository"></a>`repository`

Data type: `St2::Repository`

Release repository to enable

Default value: `$st2::repository`

##### <a name="manage_epel_repo"></a>`manage_epel_repo`

Data type: `Boolean`



Default value: ``true``

### <a name="st2repoapt"></a>`st2::repo::apt`

Apt repo for StackStorm

### <a name="st2repoyum"></a>`st2::repo::yum`

Yum repo for StackStorm

### <a name="st2rulesengine"></a>`st2::rulesengine`

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2rulesengine</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
  * https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample

#### Examples

##### Basic usage

```puppet
include st2::rulesengine
```

#### Parameters

The following parameters are available in the `st2::rulesengine` class:

* [`rulesengine_num`](#rulesengine_num)
* [`rulesengine_services`](#rulesengine_services)

##### <a name="rulesengine_num"></a>`rulesengine_num`

Data type: `Any`

The number of rulesengines to have in an active active state

Default value: `$st2::rulesengine_num`

##### <a name="rulesengine_services"></a>`rulesengine_services`

Data type: `Any`

Name of all the rulesengine services

Default value: `$st2::params::rulesengine_services`

### <a name="st2scheduler"></a>`st2::scheduler`

Normally this class is instantiated by <code>st2::profile::fullinstall</code>.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2scheduler</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
  * https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample#L251-L259

#### Examples

##### Basic usage

```puppet
include st2::scheduler
```

##### Customizing parameters

```puppet
class { 'st2::scheduler':
  sleep_interval => 60,
  gc_interval    => 120,
}
```

#### Parameters

The following parameters are available in the `st2::scheduler` class:

* [`sleep_interval`](#sleep_interval)
* [`gc_interval`](#gc_interval)
* [`pool_size`](#pool_size)
* [`scheduler_num`](#scheduler_num)
* [`scheduler_services`](#scheduler_services)

##### <a name="sleep_interval"></a>`sleep_interval`

Data type: `Any`

How long (in seconds) to sleep between each action scheduler main loop run interval.

Default value: `$st2::scheduler_sleep_interval`

##### <a name="gc_interval"></a>`gc_interval`

Data type: `Any`

How often (in seconds) to look for zombie execution requests before rescheduling them.

Default value: `$st2::scheduler_gc_interval`

##### <a name="pool_size"></a>`pool_size`

Data type: `Any`

The size of the pool used by the scheduler for scheduling executions.

Default value: `$st2::scheduler_pool_size`

##### <a name="scheduler_num"></a>`scheduler_num`

Data type: `Any`

The number of schedulers to have in an active active state

Default value: `$st2::scheduler_num`

##### <a name="scheduler_services"></a>`scheduler_services`

Data type: `Any`

Name of all the scheduler services.

Default value: `$st2::params::scheduler_services`

### <a name="st2serverdatastore_keys"></a>`st2::server::datastore_keys`

Generates and manages crypto keys for use with the StackStorm datastore

#### Examples

##### Basic Usage

```puppet
include st2::server::datastore_keys
```

##### Custom key path

```puppet
class { 'st2::server::datastore_keys':
  keys_dir => '/path/to/custom/keys',
  key_path => '/path/to/custom/keys/datastore_key.json.',
}
```

#### Parameters

The following parameters are available in the `st2::server::datastore_keys` class:

* [`conf_file`](#conf_file)
* [`keys_dir`](#keys_dir)
* [`key_path`](#key_path)

##### <a name="conf_file"></a>`conf_file`

Data type: `Any`

The path where st2 config is stored

Default value: `$st2::conf_file`

##### <a name="keys_dir"></a>`keys_dir`

Data type: `Any`

The directory where the datastore keys will be stored

Default value: `$st2::datastore_keys_dir`

##### <a name="key_path"></a>`key_path`

Data type: `Any`

Path to the key file

Default value: `$st2::datastore_key_path`

### <a name="st2stanley"></a>`st2::stanley`

Installs the default admin user for st2 (stanley).

* **Note** Will install auto-generate SSH keys of none are provided.

#### Examples

##### Basic Usage

```puppet
include st2::stanley
```

##### Custom SSH keys

```puppet
class { 'st2::stanley':
  ssh_key_type => 'ssh-rsa',
  ssh_public_key => 'AAAAAWESOMEKEY==',
  ssh_private_key => '----- BEGIN RSA PRIVATE KEY -----\nDEADBEEF\n----- END RSA PRIVATE KEY -----',
}
```

#### Parameters

The following parameters are available in the `st2::stanley` class:

* [`username`](#username)
* [`ssh_public_key`](#ssh_public_key)
* [`ssh_key_type`](#ssh_key_type)
* [`ssh_private_key`](#ssh_private_key)
* [`client`](#client)
* [`server`](#server)

##### <a name="username"></a>`username`

Data type: `Any`

Name of the stanley user

Default value: `'stanley'`

##### <a name="ssh_public_key"></a>`ssh_public_key`

Data type: `Any`

SSH Public Key without leading key-type and end email

Default value: ``undef``

##### <a name="ssh_key_type"></a>`ssh_key_type`

Data type: `Any`

Type of SSH Key (ssh-dsa/ssh-rsa)

Default value: ``undef``

##### <a name="ssh_private_key"></a>`ssh_private_key`

Data type: `Any`

Private key

Default value: ``undef``

##### <a name="client"></a>`client`

Data type: `Any`

Allow incoming connections from the defined user

Default value: ``true``

##### <a name="server"></a>`server`

Data type: `Any`

Server where connection requests originate (usually st2 server)

Default value: ``true``

### <a name="st2timersengine"></a>`st2::timersengine`

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2timersengine</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
  * https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample#L337-L343

#### Examples

##### Basic usage

```puppet
include st2::timersengine
```

##### Customizing parameters

```puppet
class { 'st2::timersengine':
  enabled  => true,
  timezone => 'America/Los_Angeles',
}
```

#### Parameters

The following parameters are available in the `st2::timersengine` class:

* [`enabled`](#enabled)
* [`timezone`](#timezone)

##### <a name="enabled"></a>`enabled`

Data type: `Any`

Specify to enable timer service.

Default value: `$st2::timersengine_enabled`

##### <a name="timezone"></a>`timezone`

Data type: `Any`

Timezone pertaining to the location where st2 is run.

Default value: `$st2::timersengine_timezone`

### <a name="st2workflowengine"></a>`st2::workflowengine`

Normally this class is instantiated by +st2::profile::fullinstall+.
However, advanced users can instantiate this class directly to configure
and manage just the <code>st2workflowengine</code> service on a single node.
Parameters for this class mirror the parameters in the st2 config.

* **See also**
  * https://github.com/StackStorm/st2/blob/master/conf/st2.conf.sample

#### Examples

##### Basic usage

```puppet
include st2::workflowengine
```

#### Parameters

The following parameters are available in the `st2::workflowengine` class:

* [`workflowengine_num`](#workflowengine_num)
* [`workflowengine_services`](#workflowengine_services)

##### <a name="workflowengine_num"></a>`workflowengine_num`

Data type: `Any`

The number of workflowengines to have in an active active state

Default value: `$st2::workflowengine_num`

##### <a name="workflowengine_services"></a>`workflowengine_services`

Data type: `Any`

Name of all the workflowengine services.

Default value: `$st2::params::workflowengine_services`

## Defined types

### <a name="st2auth_user"></a>`st2::auth_user`

Creates and manages StackStorm application users (flat_file auth only)

#### Examples

##### Basic usage

```puppet
st2::auth_user { 'st2admin':
  password => 'neato!',
}
```

#### Parameters

The following parameters are available in the `st2::auth_user` defined type:

* [`name`](#name)
* [`ensure`](#ensure)
* [`password`](#password)

##### <a name="name"></a>`name`

Name of the user

##### <a name="ensure"></a>`ensure`

Data type: `Any`

Ensure user exists or not

Default value: `present`

##### <a name="password"></a>`password`

Data type: `Any`

User's password

Default value: ``undef``

### <a name="st2clientsettings"></a>`st2::client::settings`

Generates a configuration file for the st2 CLI (st2client)

#### Examples

##### Basic usage

```puppet
st2::client::settings { 'john':
  username => 'st2_john',
  password => 'xyz123',
}
```

#### Parameters

The following parameters are available in the `st2::client::settings` defined type:

* [`name`](#name)
* [`user`](#user)
* [`homedir`](#homedir)
* [`auth`](#auth)
* [`api_url`](#api_url)
* [`auth_url`](#auth_url)
* [`base_url`](#base_url)
* [`username`](#username)
* [`password`](#password)
* [`disable_credentials`](#disable_credentials)
* [`api_version`](#api_version)
* [`cacert`](#cacert)
* [`debug`](#debug)
* [`cache_token`](#cache_token)
* [`silence_ssl_warnings`](#silence_ssl_warnings)

##### <a name="name"></a>`name`

OS-level username. Used to determine where the config file will be placed.

##### <a name="user"></a>`user`

Data type: `Any`

See name

Default value: `$name`

##### <a name="homedir"></a>`homedir`

Data type: `Any`

Path to home directory of the user.

Default value: `"/home/${name}"`

##### <a name="auth"></a>`auth`

Data type: `Any`

Is auth enabled or not.

Default value: `$st2::auth`

##### <a name="api_url"></a>`api_url`

Data type: `Any`

URL of the StackStorm API service

Default value: `$st2::cli_api_url`

##### <a name="auth_url"></a>`auth_url`

Data type: `Any`

URL of the StackStorm Auth service

Default value: `$st2::cli_auth_url`

##### <a name="base_url"></a>`base_url`

Data type: `Any`

Base URL for other StackStorm services

Default value: `$st2::cli_base_url`

##### <a name="username"></a>`username`

Data type: `Any`

Username for auth on the CLI

Default value: `$st2::cli_username`

##### <a name="password"></a>`password`

Data type: `Any`

Password for auth on the CLI

Default value: `$st2::cli_password`

##### <a name="disable_credentials"></a>`disable_credentials`

Data type: `Any`

Prevents credentials (username, password) from being written to the config file

Default value: ``false``

##### <a name="api_version"></a>`api_version`

Data type: `Any`

Version of the StackStorm API

Default value: `$st2::cli_api_version`

##### <a name="cacert"></a>`cacert`

Data type: `Any`

Path to the SSL CA certficate for the StackStorm services

Default value: `$st2::cli_cacert`

##### <a name="debug"></a>`debug`

Data type: `Any`

Enable debug mode

Default value: `$st2::cli_debug`

##### <a name="cache_token"></a>`cache_token`

Data type: `Any`

Enable cacheing authentication tokens until they expire

Default value: `$st2::cli_cache_token`

##### <a name="silence_ssl_warnings"></a>`silence_ssl_warnings`

Data type: `Any`

Enable silencing SSL warnings for self-signed certs

Default value: `$st2::cli_silence_ssl_warnings`

### <a name="st2kv"></a>`st2::kv`

Sets a value to the StackStorm Key/Value Store

#### Examples

##### Basic usage

```puppet
st2::kv { 'install_uuid':
  value => $_uuid,
}
```

#### Parameters

The following parameters are available in the `st2::kv` defined type:

* [`key`](#key)
* [`value`](#value)
* [`ensure`](#ensure)
* [`apikey`](#apikey)

##### <a name="key"></a>`key`

Data type: `Any`

Key to set

Default value: `$name`

##### <a name="value"></a>`value`

Data type: `Any`

Value of key

##### <a name="ensure"></a>`ensure`

Data type: `Any`



Default value: `present`

##### <a name="apikey"></a>`apikey`

Data type: `Any`



Default value: `$st2::cli_apikey`

### <a name="st2pack"></a>`st2::pack`

Manages a StackStorm Pack

#### Examples

##### Basic Usage

```puppet
st2::pack { 'puppet': }
```

##### Install from a custom URL

```puppet
st2::pack { 'custom':
  repo_url => 'http://github.com/myorg/stackstorm-custom.git',
}
```

#### Parameters

The following parameters are available in the `st2::pack` defined type:

* [`pack`](#pack)
* [`repo_url`](#repo_url)
* [`config`](#config)
* [`ensure`](#ensure)
* [`version`](#version)

##### <a name="pack"></a>`pack`

Data type: `Any`

Name of the pack to install.

Default value: `$name`

##### <a name="repo_url"></a>`repo_url`

Data type: `Any`

URL of the package to install when not installing from the exchange.

Default value: ``undef``

##### <a name="config"></a>`config`

Data type: `Any`

Hash that will be translated into YAML in the pack's config file after installation.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Any`



Default value: `present`

##### <a name="version"></a>`version`

Data type: `Any`



Default value: ``undef``

### <a name="st2rbac"></a>`st2::rbac`

This defined type creates RBAC resources for users

* **Note** This is an enterprise feature, and requires a license to be used.

#### Examples

##### 

```puppet
st2::rbac { 'admin':
  description => "Administrative user",
  roles       => [
    'observer',
    'my_test_role',
  ],
}
```

#### Parameters

The following parameters are available in the `st2::rbac` defined type:

* [`ensure`](#ensure)
* [`user`](#user)
* [`description`](#description)
* [`roles`](#roles)

##### <a name="ensure"></a>`ensure`

Data type: `Any`



Default value: `'present'`

##### <a name="user"></a>`user`

Data type: `Any`



Default value: `$name`

##### <a name="description"></a>`description`

Data type: `Any`



Default value: `'Created and managed by Puppet'`

##### <a name="roles"></a>`roles`

Data type: `Any`



Default value: `[]`

### <a name="st2service"></a>`st2::service`

Creates additional service for components that can be scaled out

#### Examples

##### build st2workflowengine service

```puppet
st2::service { 'st2workflowengine':
  service_name => 'st2workflowengine-rsa',
  service_num => '2',
  existing_services => ['st2workflowengine'],
}
```

#### Parameters

The following parameters are available in the `st2::service` defined type:

* [`service_name`](#service_name)
* [`service_num`](#service_num)
* [`existing_services`](#existing_services)

##### <a name="service_name"></a>`service_name`

Data type: `Any`

The service name that we are attempting to scale

##### <a name="service_num"></a>`service_num`

Data type: `Any`

The number of servicees that should be scaled out

##### <a name="existing_services"></a>`existing_services`

Data type: `Any`

The service to make sure are enabled and running. All new service
are automatically added to this.

### <a name="st2user"></a>`st2::user`

Creates an system (OS level) user for use with StackStorm

#### Examples

##### Custom SSH keys

```puppet
st2::user { 'stanley':
  ssh_key_type => 'ssh-rsa',
  ssh_public_key => 'AAAAAWESOMEKEY==',
  ssh_private_key => '----- BEGIN RSA PRIVATE KEY -----\nDEADBEEF\n----- END RSA PRIVATE KEY -----',
}
```

#### Parameters

The following parameters are available in the `st2::user` defined type:

* [`client`](#client)
* [`server`](#server)
* [`create_sudo_entry`](#create_sudo_entry)
* [`ssh_public_key`](#ssh_public_key)
* [`ssh_key_type`](#ssh_key_type)
* [`ssh_private_key`](#ssh_private_key)
* [`groups`](#groups)
* [`ssh_dir`](#ssh_dir)

##### <a name="client"></a>`client`

Data type: `Any`

Allow incoming connections from the defined user

Default value: ``true``

##### <a name="server"></a>`server`

Data type: `Any`

Server where connection requests originate (usually st2 server)

Default value: ``false``

##### <a name="create_sudo_entry"></a>`create_sudo_entry`

Data type: `Any`

Manage the sudoers entry (default: false)

Default value: ``false``

##### <a name="ssh_public_key"></a>`ssh_public_key`

Data type: `Any`

SSH Public Key without leading key-type and end email.

Default value: ``undef``

##### <a name="ssh_key_type"></a>`ssh_key_type`

Data type: `Any`

Type of SSH Key (ssh-dsa/ssh-rsa)

Default value: ``undef``

##### <a name="ssh_private_key"></a>`ssh_private_key`

Data type: `Any`

SSH Private key. If not specified, then one will be generated.

Default value: ``undef``

##### <a name="groups"></a>`groups`

Data type: `Any`

List of groups (OS level) that this user should be a member of

Default value: ``undef``

##### <a name="ssh_dir"></a>`ssh_dir`

Data type: `Any`

Directory where SSH keys will be stored

Default value: `"/home/${name}/.ssh"`

## Resource types

### <a name="st2_pack"></a>`st2_pack`

Manage st2 packs

#### Properties

The following properties are available in the `st2_pack` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `st2_pack` type.

* [`apikey`](#apikey)
* [`name`](#name)
* [`password`](#password)
* [`provider`](#provider)
* [`source`](#source)
* [`user`](#user)
* [`version`](#version)

##### <a name="apikey"></a>`apikey`

St2 apikey

##### <a name="name"></a>`name`

namevar

Name of the pack.

##### <a name="password"></a>`password`

St2 cli password

##### <a name="provider"></a>`provider`

The specific backend to use for this `st2_pack` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="source"></a>`source`

Git URL for st2 pack

##### <a name="user"></a>`user`

St2 cli user

##### <a name="version"></a>`version`

Specific pack version to install

## Functions

### <a name="st2urlencode"></a>`st2::urlencode`

Type: Ruby 4.x API

URL encodes a string

#### Examples

##### Basic usage

```puppet
st2::urlencode('xyz!123')
```

#### `st2::urlencode(String $url)`

URL encodes a string

Returns: `String` URL encoded data

##### Examples

###### Basic usage

```puppet
st2::urlencode('xyz!123')
```

##### `url`

Data type: `String`

Raw URL data to encode

### <a name="st2version_ge"></a>`st2::version_ge`

Type: Puppet Language

Determines if the StackStorm version installed on the system <code>$facts['st2_version']</code>
or the version requested by the user <code>$st2::version</code> is greater than or equal
to <code>$version</code>.

This is used to determine if this Puppet module should enable features for managing
specific versions of StackStorm. Older versions of StackStorm will not have new features
and we don't want this module to try and manage them if they're not present on the system.

Users who have old version of StackStorm installed may have <code>$st2::version = 'present'</code>
or <code>$st2::version = 'installed'</code>. In this case, we don't want to assume the user
has a new version of StackStorm or wants to upgrade. Instead, we should assume that
this the installed version of StackStorm is the version we should be using to compare.

#### Examples

##### Basic Usage

```puppet
if st2::version_ge('2.4.0') {
  # ... do something only for StackStorm version >= 2.4.0
}
```

#### `st2::version_ge(String $version)`

Determines if the StackStorm version installed on the system <code>$facts['st2_version']</code>
or the version requested by the user <code>$st2::version</code> is greater than or equal
to <code>$version</code>.

This is used to determine if this Puppet module should enable features for managing
specific versions of StackStorm. Older versions of StackStorm will not have new features
and we don't want this module to try and manage them if they're not present on the system.

Users who have old version of StackStorm installed may have <code>$st2::version = 'present'</code>
or <code>$st2::version = 'installed'</code>. In this case, we don't want to assume the user
has a new version of StackStorm or wants to upgrade. Instead, we should assume that
this the installed version of StackStorm is the version we should be using to compare.

Returns: `Boolean` True if the StackStorm version on the system or $st2::version is
>= to the +version+ parameter.

##### Examples

###### Basic Usage

```puppet
if st2::version_ge('2.4.0') {
  # ... do something only for StackStorm version >= 2.4.0
}
```

##### `version`

Data type: `String`

Version string to compare against. This should be in SemVer format

## Data types

### <a name="st2repository"></a>`St2::Repository`

Validate the type of system package repository for StackStorm

Alias of

```puppet
Enum['stable', 'unstable', 'staging-stable', 'staging-unstable']
```

## Tasks

### <a name="key_decrypt"></a>`key_decrypt`

Decrypt a StackStorm key/value pair. TODO - Remove this when the following is closed: https://github.com/StackStorm/st2/issues/4545

**Supports noop?** false

#### Parameters

##### `crypto_key_path`

Data type: `String`

Path to StackStorm crypto key

##### `keys`

Data type: `Array[Hash]`

List of key value pairs

### <a name="key_get"></a>`key_get`

Retrieve the value for a key from the StackStorm datastore

**Supports noop?** false

#### Parameters

##### `key`

Data type: `String[1]`

Key to get

##### `scope`

Data type: `Optional[String]`

Scope to retrieve the data from. Default = 'system'

##### `decrypt`

Data type: `Optional[Boolean]`

Decrypt secret if encrypted. Default = false

##### `convert`

Data type: `Optional[Boolean]`

Attempt to convert the string into a hash, array, etc by parsing it as JSON. If an error occurs the string data will be returned. Default = true

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="key_load"></a>`key_load`

Load a list of a StackStorm key/value pairs into the datastore

**Supports noop?** false

#### Parameters

##### `keys`

Data type: `Array[Hash]`

List of key value pairs. Each hash should have a 'name' and 'value' key. Example: {'name': 'mydatastorkey', 'value': 'valueinthedatastore'} . For more details , see: https://docs.stackstorm.com/datastore.html#loading-key-value-pairs-from-a-file

##### `convert`

Data type: `Optional[Boolean]`

Convert non-string types (hash, array, boolean, int, float) to a JSON string before loading it into the datastore.

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="pack_install"></a>`pack_install`

Install a list of packs

**Supports noop?** false

#### Parameters

##### `packs`

Data type: `Array[String]`

List of packs to install. This can either be the name of a pack to install from the exchange, a URL to a pack to install from git://user@domain/pack.git or https://github.com/org/pack.git, or the path to a local git repo file:///path/to/local/pack

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="pack_list"></a>`pack_list`

Get a list of packs

**Supports noop?** false

#### Parameters

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="pack_register"></a>`pack_register`

Registers a pack that exists on the filesystem

**Supports noop?** false

#### Parameters

##### `paths`

Data type: `Array[String]`

Array of directories on the local StackStorm filesystem where the pack contents currently exist and will be used to register from.

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="pack_remove"></a>`pack_remove`

Remove a list of packs

**Supports noop?** false

#### Parameters

##### `packs`

Data type: `Array[String]`

List of packs names to remove

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="rule_disable"></a>`rule_disable`

Disable a given rule

**Supports noop?** false

#### Parameters

##### `rule`

Data type: `String`

Name of a rule to disable (format: pack_name.rule_name)

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="rule_list"></a>`rule_list`

Return a list of rules.

**Supports noop?** false

#### Parameters

##### `pack`

Data type: `Optional[String]`

Name of a pack if you want to return rules only for a given pack.

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

### <a name="run"></a>`run`

Runs a StackStorm action

**Supports noop?** false

#### Parameters

##### `action`

Data type: `String`

Name of the action to execute

##### `parameters`

Data type: `Optional[Array[String]]`

Array of parameter strings to pass to the execution. Named arguments should be of the format 'param=value' positional parameters can be put in their normal order as strings.

##### `api_key`

Data type: `Optional[String]`

StackStorm API key to use for authentication (prefer this over username/password).

##### `auth_token`

Data type: `Optional[String]`

StackStorm auth token. Use this if username/password auth has already been established in a previous task and auth token is being passed around.

##### `username`

Data type: `Optional[String]`

Username to use for StackStorm authentication.

##### `password`

Data type: `Optional[String]`

Password to use for StackStorm authentication.

## Plans

### <a name="st2upgrade_mongodb"></a>`st2::upgrade_mongodb`

The default upgrade for this plan goes from 3.4 to 3.6 and ultimately to 4.0

High level steps:
- stop stackstorm
## https://docs.mongodb.com/manual/release-notes/3.6-upgrade-standalone/
- set MongoDB feature compatibility to 3.4
- change package repo to 3.8
- upgrade packages
- set MongoDB feature compatibility to 3.8
## https://docs.mongodb.com/manual/release-notes/4.0-upgrade-standalone/
- change package repo to 4.0
- upgrade packages
- set MongoDB feature compatibility to 4.0
- start stackstorm

#### Examples

##### Basic usage

```puppet
bolt plan run st2::upgrade_mongodb --targets ssh_nodes --params '{"mongo_password": "xxx"}'
```

##### Upgrading enterprise packages

```puppet
bolt plan run st2::upgrade_mongodb --targets ssh_nodes --params '{"mongo_password": "xxx", "mongo_packages": ["mongodb-enterprise-server", "mongodb-enterprise-shell", "mongodb-enterprise-tools"], "mongo_edition": "enterprise"}'
```

##### Upgrading from 3.6 to 4.0

```puppet
bolt plan run st2::upgrade_mongodb --targets ssh_nodes --params '{"mongo_password": "xxx", "upgrade_version_start": "3.8", "upgrade_version_path": ["4.0"]}'
```

##### Upgrading from 3.4 to 3.6 to 4.0

```puppet
bolt plan run st2::upgrade_mongodb --targets ssh_nodes --params '{"mongo_password": "xxx", "upgrade_version_start": "3.4", "upgrade_version_path": ["3.8", "4.0"]}'
```

#### Parameters

The following parameters are available in the `st2::upgrade_mongodb` plan:

* [`targets`](#targets)
* [`mongo_admin_db`](#mongo_admin_db)
* [`mongo_username`](#mongo_username)
* [`mongo_password`](#mongo_password)
* [`mongo_packages`](#mongo_packages)
* [`mongo_edition`](#mongo_edition)
* [`upgrade_version_start`](#upgrade_version_start)
* [`upgrade_version_path`](#upgrade_version_path)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Set of targets (MongoDB hosts) that this plan will be executed on.

##### <a name="mongo_admin_db"></a>`mongo_admin_db`

Data type: `String`

Name of the admin database for MongoDB

Default value: `'admin'`

##### <a name="mongo_username"></a>`mongo_username`

Data type: `String`

Name of the admin user on the admin database

Default value: `'admin'`

##### <a name="mongo_password"></a>`mongo_password`

Data type: `String`

Password of the admin user on the admin database

##### <a name="mongo_packages"></a>`mongo_packages`

Data type: `Array[String]`

List of MongoDB packages that will be upgraded

Default value: `['mongodb-org-server', 'mongodb-org-shell', 'mongodb-org-tools']`

##### <a name="mongo_edition"></a>`mongo_edition`

Data type: `Enum['enterprise', 'org']`

What edition of MongoDB should be setup from a repo perspective,
either 'org' for community edition, or 'enterprise' for enterprise edition.

Default value: `'org'`

##### <a name="upgrade_version_start"></a>`upgrade_version_start`

Data type: `String`

Version of MongoDB that the database is currently on, ie. where we are starting from.

Default value: `'3.4'`

##### <a name="upgrade_version_path"></a>`upgrade_version_path`

Data type: `Array[String]`

List of versions that we will upgrade through along our path to success!

Default value: `['3.6', '4.0']`
